#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_NAN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_NAN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/nan.hpp>

#endif
